/*
 * @(#)OpenType.java	1.13 98/03/18
 *
 * Copyright 1997, 1998 by Sun Microsystems, Inc.,
 * 901 San Antonio Road, Palo Alto, California, 94303, U.S.A.
 * All rights reserved.
 *
 * This software is the confidential and proprietary information
 * of Sun Microsystems, Inc. ("Confidential Information").  You
 * shall not disclose such Confidential Information and shall use
 * it only in accordance with the terms of the license agreement
 * you entered into with Sun.
 */

package java.awt.font;

/**
 * This interface represents OpenType and TrueType fonts. The goal
 * for this interface is to be able to return <i>sfnt</i> tables from
 * the font.  A particular Font object may implement this interface.
 * @version 10 Feb 1997
 */
public interface OpenType {
  
  /* 51 tag types so far */

  /**
   * Character to glyph mapping.
   */  
  public final static int       TAG_CMAP        = 0x636d6170;

  /**
   * Font header.
   */  
  public final static int       TAG_HEAD        = 0x68656164;

  /**
   * Naming table.
   */  
  public final static int       TAG_NAME        = 0x6e616d65;

  /**
   * Glyph data.
   */  
  public final static int       TAG_GLYF        = 0x676c7966;

  /**
   * Maximum profile.
   */  
  public final static int       TAG_MAXP        = 0x6d617870;

  /**
   * CVT preprogram.
   */  
  public final static int       TAG_PREP        = 0x70726570;

  /**
   * Horizontal metrics.
   */  
  public final static int       TAG_HMTX        = 0x686d7478;

  /**
   * Kerning.
   */  
  public final static int       TAG_KERN        = 0x6b65726e;

  /**
   * Horizontal device metrics.
   */  
  public final static int       TAG_HDMX        = 0x68646d78;

  /**
   * Index to location.
   */  
  public final static int       TAG_LOCA        = 0x6c6f6361;

  /**
   * Postscript Information.
   */  
  public final static int       TAG_POST        = 0x706f7374;

  /**
   * OS/2 and windows specific metrics.
   */  
  public final static int       TAG_OS2 = 0x4f532f32;

  /**
   * Control value table.
   */  
  public final static int       TAG_CVT = 0x63767420;

  /**
   * Grid_fitting and scan conversion procedure.
   */  
  public final static int       TAG_GASP        = 0x67617370;

  /**
   * Vertical device metrics.
   */  
  public final static int       TAG_VDMX        = 0x56444d58;

  /**
   * Vertical metrics.
   */  
  public final static int       TAG_VMTX        = 0x766d7478;

  /**
   * Vertical metrics header.
   */  
  public final static int       TAG_VHEA        = 0x76686561;

  /**
   * Horizontal metrics header.
   */  
  public final static int       TAG_HHEA        = 0x68686561;

  /**
   * Adobe Type 1 font data.
   */  
  public final static int       TAG_TYP1        = 0x74797031;

  /**
   * Baselint table.
   */  
  public final static int       TAG_BSLN        = 0x62736c6e;

  /**
   * Glyph substitution.
   */  
  public final static int       TAG_GSUB        = 0x47535542;

  /**
   * Digital signature.
   */  
  public final static int       TAG_DSIG        = 0x44534947;

  /**
   * Font program.
   */  
  public final static int       TAG_FPGM        = 0x6670676d;

  /**
   * Font variation.
   */  
  public final static int       TAG_FVAR        = 0x66766172;

  /**
   * Glyph variation.
   */  
  public final static int       TAG_GVAR        = 0x67766172;

  /**
   * Compact font format (Type1 font).
   */  
  public final static int       TAG_CFF = 0x43464620;

  /**
   * Multiple master supplementary data.
   */  
  public final static int       TAG_MMSD        = 0x4d4d5344;

  /**
   * Multiple master font metrics.
   */  
  public final static int       TAG_MMFX        = 0x4d4d4658;

  /**
   * Baseline data.
   */  
  public final static int       TAG_BASE        = 0x42415345;

  /**
   * Glyph definition.
   */  
  public final static int       TAG_GDEF        = 0x47444546;

  /**
   * Glyph positioning.
   */  
  public final static int       TAG_GPOS        = 0x47504f53;

  /**
   * Justification.
   */  
  public final static int       TAG_JSTF        = 0x4a535446;

  /**
   * Embedded bitmap data.
   */  
  public final static int       TAG_EBDT        = 0x45424454;

  /**
   * Embedded bitmap location.
   */  
  public final static int       TAG_EBLC        = 0x45424c43;

  /**
   * Embedded bitmap scaling.
   */  
  public final static int       TAG_EBSC        = 0x45425343;

  /**
   * Linear threshold.
   */  
  public final static int       TAG_LTSH        = 0x4c545348;

  /**
   * PCL 5 data.
   */  
  public final static int       TAG_PCLT        = 0x50434c54;

  /**
   * Accent attachment.
   */  
  public final static int       TAG_ACNT        = 0x61636e74;

  /**
   * Axis variaiton.
   */  
  public final static int       TAG_AVAR        = 0x61766172;

  /**
   * Bitmap data.
   */  
  public final static int       TAG_BDAT        = 0x62646174;

  /**
   * Bitmap location.
   */  
  public final static int       TAG_BLOC        = 0x626c6f63;

   /**
    * CVT variation.
    */  
  public final static int       TAG_CVAR        = 0x63766172;

  /**
   * Feature name.
   */  
  public final static int       TAG_FEAT        = 0x66656174;

  /**
   * Font descriptors.
   */  
  public final static int       TAG_FDSC        = 0x66647363;
 
  /**
   * Font metrics.
   */  
  public final static int       TAG_FMTX        = 0x666d7478;

  /**
   * Justification.
   */  
  public final static int       TAG_JUST        = 0x6a757374;

  /**
   * Ligature caret.
   */  
  public final static int       TAG_LCAR        = 0x6c636172;

  /**
   * Glyph metamorphosis.
   */  
  public final static int       TAG_MORT        = 0x6d6f7274;

  /**
   * Optical bounds.
   */  
  public final static int       TAG_OPBD        = 0x6d6f7274;

  /**
   * Glyph properties.
   */  
  public final static int       TAG_PROP        = 0x70726f70;

  /**
   * Tracking.
   */  
  public final static int       TAG_TRAK        = 0x7472616b;

  /**
   * Returns the version of the OpenType font.
   * 1.0 is represented as 0x00010000.
   */
  public int getVersion();

  /**
   * Returns the table as an array of bytes for a given tag. Tags for sfnt
   * tables include items like <i>cmap</i>, <i>name</i> and <i>head</i>.
   * The byte array returned is a copy of the font data in memory.
   *@ may need to give partial font table access.
   */
  public byte[] getFontTable(int sfntTag);

  /* might need to add a bunch of other methods */

}

